import * as React from "react";
import { PropertyControls, ControlType } from "framer";

const divStyle: React.CSSProperties = {
  height: "100%",
  display: "flex",
  alignItems: "end",
  justifyContent: "start",
  background: "rgba(136, 85, 255, 0.1)",
  overflow: "hidden",
  paddingLeft: 7,
  paddingBottom: 10
};

const swatchStyle: React.CSSProperties = {
  width: 60,
  height: 60,
  borderRadius: 30,
  background: "#8855FF",
  display: "flex",
  alignItems: "center",
  justifyContent: "center",
  textAlign: "center",
  color: "#fff",
  fontSize: 30,
  marginLeft: 10,
  marginTop: 10
};

interface Props {
  thumbs: Array<boolean>;
}

export class Boolean_Multiple extends React.Component<Props> {
  static defaultProps = {
    thumbs: [true, false, true, false, true]
  };

  static propertyControls: PropertyControls = {
    thumbs: {
      type: ControlType.Array,
      title: "Thumbs",
      propertyControl: {
        type: ControlType.Boolean,
        defaultValue: true,
        enabledTitle: "Up",
        disabledTitle: "Down"
      },
      defaultValue: [true, false, true, false, true],
      maxCount: 5
    }
  };

  render() {
    return (
      <div style={divStyle}>
        {this.props.thumbs.map((thumb, index) => (
          <div
            key={index}
            style={{
              ...swatchStyle,
              opacity: thumb ? 1 : 0.3
            }}
          >
            {thumb ? "👍" : "👎"}
          </div>
        ))}
      </div>
    );
  }
}
