import * as React from "react";
import { PropertyControls, ControlType } from "framer";

const divStyle: React.CSSProperties = {
  width: "100%",
  height: "100%",
  display: "flex",
  alignItems: "center",
  justifyContent: "center",
  background: "rgba(136, 85, 255, 0.1)",
  overflow: "hidden"
};

const buttonStyle: React.CSSProperties = {
  width: 120,
  height: 40,
  borderRadius: 60,
  display: "flex",
  alignItems: "center",
  justifyContent: "center",
  textAlign: "center",
  color: "#fff",
  fontSize: 14,
  fontWeight: 600,
  border: 0,
  cursor: "pointer"
};

interface Props {
  width: number;
  height: number;
  buttonColor: string;
}

export class Color extends React.Component<Props> {
  static defaultProps = {
    buttonColor: "#1199EE"
  };

  static propertyControls: PropertyControls = {
    buttonColor: {
      type: ControlType.Color,
      title: "Button color",
      defaultValue: "#1199EE"
    }
  };

  render() {
    return (
      <div
        style={{
          ...divStyle,
          width: this.props.width,
          height: this.props.height
        }}
      >
        <button
          style={{
            ...buttonStyle,
            background: this.props.buttonColor
          }}
        >
          Start
        </button>
      </div>
    );
  }
}
