import * as React from "react";
import { PropertyControls, ControlType } from "framer";

const divStyle: React.CSSProperties = {
  height: "100%",
  display: "flex",
  background: "rgba(136, 85, 255, 0.1)",
  overflow: "hidden"
};

const swatchStyle: React.CSSProperties = {
  width: 100,
  height: 40,
  borderRadius: 60,
  display: "flex",
  alignItems: "center",
  justifyContent: "center",
  textAlign: "center",
  color: "#fff",
  fontSize: 12,
  fontFamily: "Menlo",
  marginLeft: 20,
  marginTop: 20,
  padding: 5
};

interface Props {
  width: number;
  height: number;
  items: Array<string>;
}

export class Color_Multiple extends React.Component<Props> {
  static defaultProps = {
    items: ["Blue", "Red"]
  };

  static propertyControls: PropertyControls = {
    items: {
      type: ControlType.Array,
      title: "Items",
      propertyControl: {
        type: ControlType.Color,
        defaultValue: "#1199EE"
      },
      maxCount: 3,
      defaultValue: ["Blue", "Red"]
    }
  };

  render() {
    return (
      <div style={divStyle}>
        {this.props.items.map((color, index) => (
          <div
            key={index}
            style={{
              ...swatchStyle,
              background: color
            }}
          >
            {color}
          </div>
        ))}
      </div>
    );
  }
}
