import * as React from "react";
import { PropertyControls, ControlType } from "framer";

const divStyle: React.CSSProperties = {
  display: "flex",
  alignItems: "center",
  justifyContent: "center",
  background: "rgba(136, 85, 255, 0.1)",
  overflow: "hidden"
};

const buttonStyle: React.CSSProperties = {
  width: 120,
  height: 40,
  borderRadius: 60,
  display: "flex",
  alignItems: "center",
  justifyContent: "center",
  textAlign: "center",
  color: "#fff",
  fontSize: 14,
  fontWeight: 600,
  border: 0,
  background: "#1199EE"
};

interface Props {
  width: number;
  height: number;
  cursor: "pointer" | "not-allowed" | "crosshair" | "grab" | "move";
}

export class Enum extends React.Component<Props> {
  static defaultProps = {
    cursor: "pointer"
  };

  static propertyControls: PropertyControls = {
    cursor: {
      type: ControlType.Enum,
      title: "Cursor type",
      options: ["pointer", "not-allowed", "crosshair", "grab", "move"],
      optionTitles: ["Pointer", "Not allowed", "Crosshair", "Grab", "Move"]
    }
  };

  render() {
    return (
      <div
        style={{
          ...divStyle,
          width: this.props.width,
          height: this.props.height
        }}
      >
        <button
          style={{
            ...buttonStyle,
            cursor: this.props.cursor
          }}
        >
          Start
        </button>
      </div>
    );
  }
}
