import * as React from "react";
import { PropertyControls, ControlType } from "framer";

const divStyle: React.CSSProperties = {
  display: "flex",
  background: "rgba(136, 85, 255, 0.1)",
  overflow: "hidden"
};

const imageStyle: React.CSSProperties = {
  marginLeft: 20,
  marginTop: 3
};

interface Props {
  width: number;
  height: number;
  svgs: Array<string>;
}

export class File_Multiple extends React.Component<Props> {
  static defaultProps = {
    svgs: []
  };

  static propertyControls: PropertyControls = {
    svgs: {
      type: ControlType.Array,
      title: "SVGs",
      propertyControl: {
        type: ControlType.File,
        allowedFileTypes: ["svg"]
      },
      maxCount: 5
    }
  };

  render() {
    return (
      <div
        style={{
          ...divStyle,
          width: this.props.width,
          height: this.props.height
        }}
      >
        {this.props.svgs.map((url, index) => (
          <img key={index} src={url} style={imageStyle} />
        ))}
      </div>
    );
  }
}
