import * as React from "react";
import { PropertyControls, ControlType } from "framer";

const divStyle: React.CSSProperties = {
  display: "flex",
  flexWrap: "wrap",
  alignContent: "flex-start",
  alignItems: "start",
  justifyContent: "start",
  background: "rgba(136, 85, 255, 0.1)",
  overflow: "hidden"
};

const swatchStyle: React.CSSProperties = {
  width: 30,
  height: 30,
  borderRadius: 7,
  background: "#8855FF"
};

interface Props {
  width: number;
  height: number;
  margin: number;
  marginPerSide: boolean;
  marginTop: number;
  marginRight: number;
  marginBottom: number;
  marginLeft: number;
}

export class FusedNumber extends React.Component<Props> {
  static defaultProps = {
    margin: 1,
    marginPerSide: false,
    marginTop: 0,
    marginRight: 4,
    marginBottom: 4,
    marginLeft: 0
  };

  static propertyControls: PropertyControls = {
    margin: {
      type: ControlType.FusedNumber,
      title: "Margin",
      toggleKey: "marginPerSide",
      toggleTitles: ["All Sides", "Per Side"],
      valueKeys: ["marginTop", "marginRight", "marginBottom", "marginLeft"],
      valueLabels: ["Top", "Right", "Bottom", "Left"],
      min: 0
    }
  };

  render() {
    let marginProperties = {};

    if (this.props.marginPerSide) {
      marginProperties = {
        marginTop: this.props.marginTop,
        marginRight: this.props.marginRight,
        marginBottom: this.props.marginBottom,
        marginLeft: this.props.marginLeft
      };
    } else {
      marginProperties = {
        margin: this.props.margin
      };
    }

    let swatches = [];
    for (let i = 0; i < 22; i++) {
      swatches.push(
        <div
          key={i}
          style={{
            ...swatchStyle,
            ...marginProperties
          }}
        />
      );
    }

    return (
      <div
        style={{
          ...divStyle,
          width: this.props.width,
          height: this.props.height
        }}
      >
        {swatches}
      </div>
    );
  }
}
