import * as React from "react";
import { PropertyControls, ControlType } from "framer";

const divStyle: React.CSSProperties = {
  display: "flex",
  background: "rgba(136, 85, 255, 0.1)",
  overflow: "hidden",
  paddingLeft: 7
};

const imageStyle: React.CSSProperties = {
  width: 60,
  height: 60,
  borderRadius: 30,
  background: "#8855FF",
  marginLeft: 10,
  marginTop: 10
};

interface Props {
  width: number;
  height: number;
  images: Array<string>;
}

export class Image_Multiple extends React.Component<Props> {
  static defaultProps = {
    images: []
  };

  static propertyControls: PropertyControls = {
    images: {
      type: ControlType.Array,
      title: "Images",
      propertyControl: {
        type: ControlType.Image
      },
      maxCount: 5
    }
  };

  render() {
    return (
      <div
        style={{
          ...divStyle,
          width: this.props.width,
          height: this.props.height
        }}
      >
        {this.props.images.map((image, index) => (
          <img key={index} src={image} style={imageStyle} />
        ))}
      </div>
    );
  }
}
