import * as React from "react";
import { PropertyControls, ControlType } from "framer";

const divStyle: React.CSSProperties = {
  height: "100%",
  display: "flex",
  alignItems: "center",
  justifyContent: "center",
  textAlign: "center",
  color: "#8855FF",
  background: "rgba(136, 85, 255, 0.1)",
  overflow: "hidden",
  fontSize: 55
};

const spanStyle: React.CSSProperties = {
  margin: 10
};

interface Props {
  negativeOrPositive: number;
  steppable: number;
}

export class Number extends React.Component<Props> {
  static defaultProps = {
    negativeOrPositive: 0,
    steppable: 6
  };

  static propertyControls: PropertyControls = {
    negativeOrPositive: {
      type: ControlType.Number,
      title: "Pos. or neg.",
      defaultValue: 0,
      unit: " º",
      min: -50,
      max: 50,
      step: 0.1
    },
    steppable: {
      type: ControlType.Number,
      title: "Percentage",
      defaultValue: 6,
      unit: " %",
      min: 0,
      max: 100,
      step: 10,
      displayStepper: true
    }
  };

  render() {
    return (
      <div style={divStyle}>
        <p>
          <span style={spanStyle}>{this.props.negativeOrPositive}º</span>
          <span style={spanStyle}>—</span>
          <span style={spanStyle}>{this.props.steppable}%</span>
        </p>
      </div>
    );
  }
}
