import * as React from "react";
import { PropertyControls, ControlType } from "framer";

const divStyle: React.CSSProperties = {
  height: "100%",
  display: "flex",
  alignItems: "end",
  justifyContent: "start",
  background: "rgba(136, 85, 255, 0.1)",
  overflow: "hidden",
  paddingLeft: 10,
  paddingBottom: 10
};

const barStyle: React.CSSProperties = {
  width: 30,
  background: "#8855FF",
  marginLeft: 10,
  marginTop: "auto"
};

interface Props {
  values: Array<number>;
}

export class Number_Multiple extends React.Component<Props> {
  static defaultProps = {
    values: [30, 60, 20, 10]
  };

  static propertyControls: PropertyControls = {
    values: {
      type: ControlType.Array,
      title: "Values",
      propertyControl: {
        type: ControlType.Number,
        max: 60,
        defaultValue: 30
      },
      defaultValue: [30, 60, 20, 10],
      maxCount: 8
    }
  };

  render() {
    return (
      <div style={divStyle}>
        {this.props.values.map((value, index) => (
          <div
            key={index}
            style={{
              ...barStyle,
              height: value
            }}
          />
        ))}
      </div>
    );
  }
}
